@@ -20,7 +20,7 @@
  *
  *
  * nessus-fetch is a simple utility to retrieve Nessus plugins from nessus.org
- * $Id: nessus-fetch.c,v 1.1.2.10 2005/03/17 01:15:23 renaud Exp $
+ * $Id: nessus-fetch.c,v 1.1.2.13 2005/07/21 16:34:01 renaud Exp $
  */
 #include <includes.h>
 
@@ -32,6 +32,8 @@
 #define WWW_NESSUS_ORG "www.nessus.org"
 #define PLUGINS_NESSUS_ORG "plugins.nessus.org" 
 
+#define SOCKET_TIMEOUT 90
+
 #define ERROR_PREFIX "@ERROR@:"
 #define SUCCESS_MSG  "@SUCCESS@"
 #define CONFIG_FILE "nessus-fetch.rc"
@@ -559,7 +561,72 @@ static struct arglist * mkhostinfo(char * hostname)
 
 
 /*--------------------- Register a user -------------------------------------*/
-static int do_register( char * serial )
+static void update_plugins(int argc, char ** argv)
+{
+ char * ptr;
+ char path[1024];
+ char * my_argv[] = { "nessus-update-plugins", NULL };
+ pid_t pid;
+ int e;
+
+ printf("Now fetching the newest plugin set from plugins.nessus.org...\n");
+
+ ptr = find_in_path("nessus-update-plugins", 0);
+ if ( ptr == NULL )
+ {
+  strncpy(path, argv[0], sizeof(path) - strlen("nessus-update-plugins") );
+  path[sizeof(path) - strlen("nessus-update-plugins") ] = '\0';
+  if ( path[0] == '/' ) 
+	{
+	 ptr = strstr(path, "/bin/");
+	 if ( ptr != NULL )
+         {
+	  ptr[0] = '\0';
+	  strncat(path, "/sbin/nessus-update-plugins", sizeof(path) - strlen(path) - 1);
+	  path[sizeof(path) - 1] = '\0';
+	  ptr = &(path[0]);
+         }
+	}
+  else ptr = NULL;
+ }
+ else 
+  {
+  snprintf(path, sizeof(path), "%s/nessus-update-plugins", ptr);
+  ptr = &(path[0]);
+  }
+
+ if ( ptr == NULL )
+ {
+  fprintf(stderr, "nessus-update-plugins could not be found in your $PATH\n");
+  exit(1);
+ }
+ pid = fork();
+ if ( pid == 0 )
+ {
+  if ( execv(ptr, my_argv) < 0 ) 
+   fprintf(stderr, "Could not execute %s - %s\n", ptr, strerror(errno));
+  exit(0);
+ }
+ else if ( pid < 0 ) {
+	fprintf(stderr, "fork() failed (%s)\n", strerror(errno));
+	exit(1);
+	}
+ 
+ do {
+	errno = 0;
+	e = waitpid(pid, NULL, 0);
+    } while ( e < 0 && errno == EINTR );
+
+ 
+ printf("Your Nessus installation is now up-to-date.\nMake sure to call regularly use the command 'nessus-update-plugins' to stay up-to-date\n");
+ printf("To automate the update process, please visit <http://www.nessus.org/documentation/index.php?doc=cron>\n");
+ printf("\n");
+ 
+ exit(0);
+}
+
+
+static int do_register( char * serial, int argc, char ** argv )
 {
  char * req, * result;
  char str[1024];
@@ -581,7 +648,7 @@ static int do_register( char * serial )
  if ( prefs.proxy && prefs.proxy_port )
   soc = proxy_connect_method(PLUGINS_NESSUS_ORG, HTTPS_PORT, &prefs, hostinfo);
  else
-  soc = open_stream_connection(hostinfo, HTTPS_PORT, NESSUS_ENCAPS_TLSv1,  60);
+  soc = open_stream_connection(hostinfo, HTTPS_PORT, NESSUS_ENCAPS_TLSv1,  SOCKET_TIMEOUT);
 
  if ( soc < 0 ) 
  {
@@ -622,6 +689,7 @@ static int do_register( char * serial )
   prefs.password = password;
   save_preferences(&prefs);
   printf("Your activation code has been registered properly - thank you.\n");
+  update_plugins(argc, argv);
   exit(0);
  }
  else if ( strncmp(result, "EEXIST", strlen("EEXIST")) == 0 )
@@ -658,7 +726,7 @@ int proxy_connect_method(char * hostname, int port, struct preferences * prefs,
 	}
 	else proxy_auth[0] = '\0';
 
-  	soc = open_stream_connection ( hostinfo, atoi(prefs->proxy_port), NESSUS_ENCAPS_IP, 60 );
+  	soc = open_stream_connection ( hostinfo, atoi(prefs->proxy_port), NESSUS_ENCAPS_IP, SOCKET_TIMEOUT );
        fd = nessus_get_socket_from_connection(soc); 
 	snprintf(buf, sizeof(buf), "CONNECT %s:%d HTTP/1.0\r\nUser-Agent: Mozilla/4.73 (Win95;I)\r\n%s\r\n", hostname, port, proxy_auth);
 	write_stream_connection ( soc, buf, strlen(buf) );
@@ -702,7 +770,7 @@ int proxy_connect_method(char * hostname, int port, struct preferences * prefs,
 	SSL_set_connect_state(ssl);
   
         unblock_socket(fd);
-      if (ssl_connect_timeout(ssl, 15) <= 0)
+      if (ssl_connect_timeout(ssl, SOCKET_TIMEOUT) <= 0)
         {
           fprintf(stderr, "SSL_connect failed\n");
           exit (1);
@@ -754,13 +822,13 @@ void fetch_file(int encaps, int port, char * hostname, char * path, char * filen
 	 proxy = 0;
 	}
   else 
-	soc = open_stream_connection ( hostinfo, atoi(prefs.proxy_port), NESSUS_ENCAPS_IP, 60 );
+	soc = open_stream_connection ( hostinfo, atoi(prefs.proxy_port), NESSUS_ENCAPS_IP, SOCKET_TIMEOUT );
  }
  else {
  if ( encaps > 0 )
-  soc = open_stream_connection ( hostinfo, ( prefs.proxy && prefs.proxy_port ) ? atoi(prefs.proxy_port) : port, encaps, 60 );
+  soc = open_stream_connection ( hostinfo, ( prefs.proxy && prefs.proxy_port ) ? atoi(prefs.proxy_port) : port, encaps, SOCKET_TIMEOUT );
  else
-  soc = open_stream_connection ( hostinfo, ( prefs.proxy && prefs.proxy_port ) ? atoi(prefs.proxy_port) : port, NESSUS_ENCAPS_TLSv1, 60 );
+  soc = open_stream_connection ( hostinfo, ( prefs.proxy && prefs.proxy_port ) ? atoi(prefs.proxy_port) : port, NESSUS_ENCAPS_TLSv1, SOCKET_TIMEOUT );
  }
 
 
@@ -920,7 +988,7 @@ int main(int argc, char ** argv)
    exit(1);
   }
   serial = argv[2];
-  do_register(serial);  
+  do_register(serial, argc, argv);  
   exit(1);
  }
  else if ( argc == 2 && strcmp(argv[1], "--plugins") == 0 )
