@@ -895,7 +895,7 @@ create_host_report(struct arglist * host)
    /*
     * Make a pie
     */
-    if(total)
+    if(total > 1)
     {
     pie = fopen("pie_risks.gif", "wb");
     GDCPIE_other_threshold = -1;
@@ -909,7 +909,7 @@ create_host_report(struct arglist * host)
     GDCPIE_label_size = GDC_SMALL;
     GDCPIE_title_size = GDC_MEDBOLD;
     GDCPIE_3d_angle  = 45;
-    GDCPIE_explode   = expl;
+    if ( total > 1 ) GDCPIE_explode   = expl;
     GDCPIE_Color = clr;
     GDCPIE_BGColor = 0xFFFFFFL;
     GDC_generate_gif = TRUE;
@@ -1044,7 +1044,7 @@ static int html_make_index(hosts)
    
    expl[num_risks-1] = 20;
    
-   if(num_risks)
+   if(num_risks > 1)
    {			
     pie = fopen("pie_risks.gif", "wb");
     GDCPIE_title = "Security Risks";
@@ -1195,7 +1195,7 @@ static int html_make_index(hosts)
     names[1] = "Others";
 
 
-    if (values[1] != 0 )
+    if (values[1] != 0 && total > 1 )
     {
     pie = fopen("pie_most.gif", "wb");
     GDCPIE_other_threshold = -1;
@@ -1210,9 +1210,9 @@ static int html_make_index(hosts)
     GDCPIE_EdgeColor = 0x000000L;
     GDCPIE_missing = NULL;
     GDCPIE_percent_labels = GDCPIE_PCT_RIGHT;
-   pie_gif(480, 360, pie, GDC_3DPIE, 2,names, values);
-   fclose(pie);
-   insert_img(f, "pie_most.gif");
+    pie_gif(480, 360, pie, GDC_3DPIE, 2,names, values);
+    fclose(pie);
+    insert_img(f, "pie_most.gif");
      }
     }
     }
