@@ -419,6 +419,23 @@ xml_plugins (FILE* fd, int indent)
 
  xml_fprintf (fd, indent, "<plugins>\n");
 
+  t = Scanners;
+  if (t && t->type == ARG_ARGLIST)
+  {
+  while (t->next)
+  {
+     struct arglist * u = t->value;
+     if (arg_get_value (u, "ENABLED"))
+     {
+      xml_plugins_plugin(fd, indent+1, u);
+     }
+
+    t = t->next;
+    }
+  }
+  else
+   xml_fprintf (fd, indent+1, "<error txt=\"No scanners list.\"/>\n");
+
   t = Plugins;
   if (t && t->type == ARG_ARGLIST)
   {
@@ -454,7 +471,7 @@ getrisk (char * str)
  }
  else
  {
-  return strcpy (bck, "WARNING: no 'Risk Factor' found !");
+  return strcpy (bck, "Unknown");
  }
 }
 
