@@ -251,7 +251,7 @@ check_user(char * user, char * password, char * dname)
             
        strncpy(p, password, n);
 
-       MD5(seed, strlen(seed), h2);
+       MD5((unsigned char*)seed, strlen(seed), (unsigned char*)h2);
        if (memcmp(h1, h2, MD5_DIGEST_LENGTH) != 0)
 	 {
 	   return BAD_LOGIN_ATTEMPT;
